@@ -458,7 +458,10 @@ class FITSFigure(Layers, Regions, Deprecated):
         '''
         Center the image on a given position and with a given radius.
 
-        Either the radius or width/heigh arguments should be specified.
+        Either the radius or width/heigh arguments should be specified. The
+        units of the radius or width/height should be the same as the world
+        coordinates in the WCS. For images of the sky, this is often (but not
+        always) degrees.
 
         Parameters
         ----------
@@ -480,14 +483,14 @@ class FITSFigure(Layers, Regions, Deprecated):
 
         xpix, ypix = wcs_util.world2pix(self._wcs, x, y)
 
-        pixel_scale = wcs_util.pixel_scale(self._wcs)
+        sx, sy = wcs_util.pixel_scale(self._wcs)
 
         if radius:
-            dx_pix = radius / pixel_scale
-            dy_pix = radius / pixel_scale
+            dx_pix = radius / sx
+            dy_pix = radius / sy
         elif width and height:
-            dx_pix = width / pixel_scale / 2.
-            dy_pix = height / pixel_scale / 2.
+            dx_pix = width / sx * 0.5
+            dy_pix = height / sy * 0.5
         else:
             raise Exception("Need to specify either radius= or width= and height= arguments")
 
@@ -994,8 +997,8 @@ class FITSFigure(Layers, Regions, Deprecated):
         kwargs
             Additional keyword arguments (such as facecolor, edgecolor, alpha,
             or linewidth) are passed to Matplotlib
-            :class:`~matplotlib.patches.Circle` class, and can be used to
-            control the appearance of the circles.
+            :class:`~matplotlib.collections.PatchCollection` class, and can be
+            used to control the appearance of the circles.
         '''
 
         if np.isscalar(xw):
@@ -1024,13 +1027,11 @@ class FITSFigure(Layers, Regions, Deprecated):
 
         patches = []
         for i in range(len(xp)):
-            patches.append(Circle((xp[i], yp[i]), radius=rp[i], **kwargs))
+            patches.append(Circle((xp[i], yp[i]), radius=rp[i]))
 
-        p = PatchCollection(patches, match_original=True)
-
-        # Due to a bug in matplotlib, we have to reset the facecolor
-        if 'facecolor' in kwargs:
-            p.set_facecolor(kwargs['facecolor'])
+        # Due to bugs in matplotlib, we need to pass the patch properties
+        # directly to the PatchCollection rather than use match_original.
+        p = PatchCollection(patches, **kwargs)
 
         if zorder is not None:
             p.zorder = zorder
@@ -1076,8 +1077,8 @@ class FITSFigure(Layers, Regions, Deprecated):
         kwargs
             Additional keyword arguments (such as facecolor, edgecolor, alpha,
             or linewidth) are passed to Matplotlib
-            :class:`~matplotlib.patches.Ellipse` class, and can be used to
-            control the appearance of the ellipses.
+            :class:`~matplotlib.collections.PatchCollection` class, and can be
+            used to control the appearance of the ellipses.
         '''
 
         if np.isscalar(xw):
@@ -1118,13 +1119,11 @@ class FITSFigure(Layers, Regions, Deprecated):
 
         patches = []
         for i in range(len(xp)):
-            patches.append(Ellipse((xp[i], yp[i]), width=wp[i], height=hp[i], angle=ap[i], **kwargs))
+            patches.append(Ellipse((xp[i], yp[i]), width=wp[i], height=hp[i], angle=ap[i]))
 
-        p = PatchCollection(patches, match_original=True)
-
-        # Due to a bug in matplotlib, we have to reset the facecolor
-        if 'facecolor' in kwargs:
-            p.set_facecolor(kwargs['facecolor'])
+        # Due to bugs in matplotlib, we need to pass the patch properties
+        # directly to the PatchCollection rather than use match_original.
+        p = PatchCollection(patches, **kwargs)
 
         if zorder is not None:
             p.zorder = zorder
@@ -1166,8 +1165,8 @@ class FITSFigure(Layers, Regions, Deprecated):
         kwargs
             Additional keyword arguments (such as facecolor, edgecolor, alpha,
             or linewidth) are passed to Matplotlib
-            :class:`~matplotlib.patches.Rectangle` class, and can be used to
-            control the appearance of the rectangles.
+            :class:`~matplotlib.collections.PatchCollection` class, and can be
+            used to control the appearance of the rectangles.
         '''
 
         if np.isscalar(xw):
@@ -1204,13 +1203,11 @@ class FITSFigure(Layers, Regions, Deprecated):
         xp = xp - wp / 2.
         yp = yp - hp / 2.
         for i in range(len(xp)):
-            patches.append(Rectangle((xp[i], yp[i]), width=wp[i], height=hp[i], **kwargs))
+            patches.append(Rectangle((xp[i], yp[i]), width=wp[i], height=hp[i]))
 
-        p = PatchCollection(patches, match_original=True)
-
-        # Due to a bug in matplotlib, we have to reset the facecolor
-        if 'facecolor' in kwargs:
-            p.set_facecolor(kwargs['facecolor'])
+        # Due to bugs in matplotlib, we need to pass the patch properties
+        # directly to the PatchCollection rather than use match_original.
+        p = PatchCollection(patches, **kwargs)
 
         if zorder is not None:
             p.zorder = zorder
@@ -1275,7 +1272,7 @@ class FITSFigure(Layers, Regions, Deprecated):
 
     @auto_refresh
     def show_arrows(self, x, y, dx, dy, width='auto', head_width='auto',
-                    head_length='auto', layer=False, zorder=None, **kwargs):
+                    head_length='auto', length_includes_head=True, layer=False, zorder=None, **kwargs):
         '''
         Overlay arrows on the current plot.
 
@@ -1299,21 +1296,21 @@ class FITSFigure(Layers, Regions, Deprecated):
             The length of the arrow head, in pixels (default: 5% of the
             arrow length)
 
+        length_includes_head : bool, optional
+            Whether the head includes the length
+
         layer : str, optional
             The name of the arrow(s) layer. This is useful for giving
             custom names to layers (instead of line_set_n) and for
             replacing existing layers.
 
         kwargs
-            Additional keyword arguments (such as color, offsets, linestyle,
+            Additional keyword arguments (such as facecolor, edgecolor, alpha,
             or linewidth) are passed to Matplotlib
-            :class:`~matplotlib.patches.FancyArrow` class, and can be used to
-            control the appearance of the arrows.
+            :class:`~matplotlib.collections.PatchCollection` class, and can be
+            used to control the appearance of the arrows.
         '''
 
-        if 'length_includes_head' not in kwargs:
-            kwargs['length_includes_head'] = True
-
         if layer:
             self.remove_layer(layer, raise_exception=False)
 
@@ -1328,27 +1325,23 @@ class FITSFigure(Layers, Regions, Deprecated):
             xp2, yp2 = wcs_util.world2pix(self._wcs, x[i] + dx[i], y[i] + dy[i])
 
             if width == 'auto':
-                kwargs['width'] = 0.02 * np.sqrt((xp2 - xp1) ** 2 + (yp2 - yp1) ** 2)
-            else:
-                kwargs['width'] = width
+                width = 0.02 * np.sqrt((xp2 - xp1) ** 2 + (yp2 - yp1) ** 2)
 
             if head_width == 'auto':
-                kwargs['head_width'] = 0.1 * np.sqrt((xp2 - xp1) ** 2 + (yp2 - yp1) ** 2)
-            else:
-                kwargs['head_width'] = head_width
+                head_width = 0.1 * np.sqrt((xp2 - xp1) ** 2 + (yp2 - yp1) ** 2)
 
             if head_length == 'auto':
-                kwargs['head_length'] = 0.1 * np.sqrt((xp2 - xp1) ** 2 + (yp2 - yp1) ** 2)
-            else:
-                kwargs['head_length'] = head_length
+                head_length = 0.1 * np.sqrt((xp2 - xp1) ** 2 + (yp2 - yp1) ** 2)
 
-            arrows.append(FancyArrow(xp1, yp1, xp2 - xp1, yp2 - yp1, **kwargs))
+            arrows.append(FancyArrow(xp1, yp1, xp2 - xp1, yp2 - yp1,
+                                     width=width, head_width=head_width,
+                                     head_length=head_length,
+                                     length_includes_head=length_includes_head)
+                                     )
 
-        p = PatchCollection(arrows, match_original=True)
-
-        # Due to a bug in matplotlib, we have to reset the facecolor
-        if 'facecolor' in kwargs:
-            p.set_facecolor(kwargs['facecolor'])
+        # Due to bugs in matplotlib, we need to pass the patch properties
+        # directly to the PatchCollection rather than use match_original.
+        p = PatchCollection(arrows, **kwargs)
 
         if zorder is not None:
             p.zorder = zorder
@@ -1383,8 +1376,8 @@ class FITSFigure(Layers, Regions, Deprecated):
         kwargs
             Additional keyword arguments (such as facecolor, edgecolor, alpha,
             or linewidth) are passed to Matplotlib
-            :class:`~matplotlib.patches.Polygon` class, and can be used to
-            control the appearance of the polygons.
+            :class:`~matplotlib.collections.PatchCollection` class, and can be
+            used to control the appearance of the polygons.
         '''
 
         if not 'facecolor' in kwargs:
@@ -1418,11 +1411,9 @@ class FITSFigure(Layers, Regions, Deprecated):
         for i in range(len(pix_polygon_list)):
             patches.append(Polygon(pix_polygon_list[i], **kwargs))
 
-        p = PatchCollection(patches, match_original=True)
-
-        # Due to a bug in matplotlib, we have to reset the facecolor
-        if 'facecolor' in kwargs:
-            p.set_facecolor(kwargs['facecolor'])
+        # Due to bugs in matplotlib, we need to pass the patch properties
+        # directly to the PatchCollection rather than use match_original.
+        p = PatchCollection(patches, **kwargs)
 
         if zorder is not None:
             p.zorder = zorder
